@@ -2,6 +2,7 @@ import yaml
 import re
 import logging
 import pkg_resources
+import urlparse
 
 from pywb.utils.dsrules import BaseRule, RuleSet
 
@@ -12,11 +13,6 @@ from query import CDXQuery
 
 #=================================================================
 def load_domain_specific_cdx_rules(ds_rules_file, surt_ordered):
-    """
-    >>> (canon, fuzzy) = load_domain_specific_cdx_rules(None, True)
-    >>> canon('http://test.example.example/path/index.html?a=b&id=value&c=d')
-    'example,example,test)/path/index.html?id=value'
-    """
     canon = None
     fuzzy = None
 
@@ -89,7 +85,8 @@ class FuzzyQuery:
 
             groups = m.groups()
             for g in groups:
-                filter_.append(rule.filter.format(g))
+                for f in matched_rule.filter:
+                    filter_.append(f.format(g))
 
             break
 
@@ -104,9 +101,14 @@ class FuzzyQuery:
         if inx > 0:
             url = url[:inx + 1]
 
+        if matched_rule.match_type == 'domain':
+            host = urlparse.urlsplit(url).netloc
+            # remove the subdomain
+            url = host.split('.', 1)[1]
+
         params = query.params
         params.update({'url': url,
-                       'matchType': 'prefix',
+                       'matchType': matched_rule.match_type,
                        'filter': filter_})
 
         if 'reverse' in params:
@@ -115,12 +117,16 @@ class FuzzyQuery:
         if 'closest' in params:
             del params['closest']
 
+        if 'end_key' in params:
+            del params['end_key']
+
         return params
 
 
 #=================================================================
 class CDXDomainSpecificRule(BaseRule):
-    DEFAULT_FILTER = '~urlkey:{0}'
+    DEFAULT_FILTER = ['~urlkey:{0}']
+    DEFAULT_MATCH_TYPE = 'prefix'
 
     def __init__(self, name, config):
         super(CDXDomainSpecificRule, self).__init__(name, config)
@@ -129,10 +135,12 @@ class CDXDomainSpecificRule(BaseRule):
             self.regex = self.make_regex(config)
             self.replace = None
             self.filter = self.DEFAULT_FILTER
+            self.match_type = self.DEFAULT_MATCH_TYPE
         else:
             self.regex = self.make_regex(config.get('match'))
             self.replace = config.get('replace')
             self.filter = config.get('filter', self.DEFAULT_FILTER)
+            self.match_type = config.get('type', self.DEFAULT_MATCH_TYPE)
 
     def unsurt(self):
         """
@@ -149,24 +157,24 @@ class CDXDomainSpecificRule(BaseRule):
 
     @staticmethod
     def make_regex(config):
+        # just query args
         if isinstance(config, list):
             string = CDXDomainSpecificRule.make_query_match_regex(config)
-        # assumes string
+
+        # split out base and args
+        elif isinstance(config, dict):
+            string = config.get('regex', '')
+            string += CDXDomainSpecificRule.make_query_match_regex(
+                      config.get('args', []))
+
+        # else assume string
         else:
-            string = config
+            string = str(config)
 
         return re.compile(string)
 
     @staticmethod
     def make_query_match_regex(params_list):
-        r"""
-        >>> CDXDomainSpecificRule.make_query_match_regex(['param1', 'id', 'abc'])
-        '[?&](abc=[^&]+).*[?&](id=[^&]+).*[?&](param1=[^&]+)'
-
-        >>> CDXDomainSpecificRule.make_query_match_regex(['id[0]', 'abc()'])
-        '[?&](abc\\(\\)=[^&]+).*[?&](id\\[0\\]=[^&]+)'
-
-        """
         params_list.sort()
 
         def conv(value):
@@ -175,8 +183,3 @@ class CDXDomainSpecificRule(BaseRule):
         params_list = map(conv, params_list)
         final_str = '.*'.join(params_list)
         return final_str
-
-
-if __name__ == "__main__":
-    import doctest
-    doctest.testmod()
