@@ -98,7 +98,7 @@ class TestWb:
 
         assert '"20140127171238"' in resp.body
         assert 'wb.js' in resp.body
-        assert 'WB_wombat_init' in resp.body
+        assert 'new _WBWombat' in resp.body, resp.body
         assert '/pywb/20140127171238/http://www.iana.org/time-zones"' in resp.body
 
     def test_replay_non_frame_content(self):
@@ -133,6 +133,11 @@ class TestWb:
         assert 'wb.js' in resp.body
         assert '/pywb/20130729195151/http://www.iana.org/domains/example"' in resp.body
 
+    def test_video_info_not_found(self):
+        # not actually archived, but ensure video info path is tested
+        resp = self.testapp.get('/pywb/vi_/https://www.youtube.com/watch?v=DjFZyFWSt1M', status=404)
+        assert resp.status_int == 404
+
     def test_replay_cdx_mod(self):
         resp = self.testapp.get('/pywb/20140127171239cdx_/http://www.iana.org/_css/2013.1/print.css')
         self._assert_basic_text(resp)
@@ -149,7 +154,7 @@ class TestWb:
         assert 'wb.js' in resp.body
 
         # no wombat present
-        assert 'WB_wombat_init' not in resp.body
+        assert '_WBWombat' not in resp.body
 
         # url not rewritten
         #assert '"http://www.iana.org/domains/example"' in resp.body
@@ -161,9 +166,54 @@ class TestWb:
         # no wb header insertion
         assert 'wb.js' not in resp.body
 
+        assert resp.content_length == 1270, resp.content_length
+
         # original unrewritten url present
         assert '"http://www.iana.org/domains/example"' in resp.body
 
+    def test_replay_range_cache_content(self):
+        headers = [('Range', 'bytes=0-200')]
+        resp = self.testapp.get('/pywb/20140127171250id_/http://example.com', headers=headers)
+
+        assert resp.status_int == 206
+        assert resp.headers['Accept-Ranges'] == 'bytes'
+        assert resp.headers['Content-Range'] == 'bytes 0-200/1270', resp.headers['Content-Range']
+        assert resp.content_length == 201, resp.content_length
+
+        assert 'wb.js' not in resp.body
+
+    def test_replay_content_ignore_range(self):
+        headers = [('Range', 'bytes=0-200')]
+        resp = self.testapp.get('/pywb-norange/20140127171251id_/http://example.com', headers=headers)
+
+        # range request ignored
+        assert resp.status_int == 200
+
+        # full response
+        assert resp.content_length == 1270, resp.content_length
+
+        # identity, no header insertion
+        assert 'wb.js' not in resp.body
+
+    def test_replay_range_cache_content_bound_end(self):
+        headers = [('Range', 'bytes=10-10000')]
+        resp = self.testapp.get('/pywb/20140127171251id_/http://example.com', headers=headers)
+
+        assert resp.status_int == 206
+        assert resp.headers['Accept-Ranges'] == 'bytes'
+        assert resp.headers['Content-Range'] == 'bytes 10-1269/1270', resp.headers['Content-Range']
+        assert resp.content_length == 1260, resp.content_length
+        assert len(resp.body) == resp.content_length
+
+        assert 'wb.js' not in resp.body
+
+    def test_replay_redir_no_cache(self):
+        headers = [('Range', 'bytes=10-10000')]
+        # Range ignored
+        resp = self.testapp.get('/pywb/20140126200927/http://www.iana.org/domains/root/db/', headers=headers)
+        assert resp.content_length == 0
+        assert resp.status_int == 302
+
     def test_replay_identity_2_arcgz(self):
         resp = self.testapp.get('/pywb/20140216050221id_/http://arc.gz.test.example.com')
 
